==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/dc/controller/DcDrawrecycleInfoController.java <==
package com.ejianc.business.dc.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dc.bean.DcDrawrecycleDrwgrpinfoEntity;
import com.ejianc.business.dc.bean.DcDrawrecycleInfoEntity;
import com.ejianc.business.dc.bean.DcDrwgrpInfoEntity;
import com.ejianc.business.dc.enumUtils.RecycleEnum;
import com.ejianc.business.dc.enumUtils.YesOrNoEnum;
import com.ejianc.business.dc.service.IDcDrawrecycleDrwgrpinfoService;
import com.ejianc.business.dc.service.IDcDrawrecycleInfoService;
import com.ejianc.business.dc.service.IDcDrwgrpInfoService;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 图纸回收
 *
 * @author generator
 */
@Controller
@RequestMapping("dcDrawrecycleInfo")
public class DcDrawrecycleInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "DC_DRAWRECYCLE_CODE";//此处需要根据实际修改

    @Autowired
    private IDcDrawrecycleInfoService service;

    @Autowired
    private IDcDrawrecycleDrwgrpinfoService dcDrawrecycleDrwgrpinfoService;

    @Autowired
    private IDcDrwgrpInfoService dcDrwgrpInfoService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> saveOrUpdate(@RequestBody DcDrawrecycleInfoVO saveOrUpdateVO) {
        DcDrawrecycleInfoEntity entity = BeanMapper.map(saveOrUpdateVO, DcDrawrecycleInfoEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            entity.setRecycleSts("N");
            entity.setCreateDeptId(sessionManager.getUserContext().getDeptId());
        }
        service.saveOrUpdate(entity, false);
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> queryDetail(Long id) {
        DcDrawrecycleInfoEntity entity = service.selectById(id);
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        vo.setRecycleStsCn(RecycleEnum.getEnumByCode(vo.getRecycleSts()).getName());
        vo.getDcDrawrecycleDrwgrpinfoList().forEach(v -> v.setPaperFlagCn(YesOrNoEnum.getEnumByCode(v.getPaperFlag()).getName()));
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    @RequestMapping(value = "/recycle", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> recycle(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), vo);
                CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
                if (billCode.isSuccess()) {
                    UserContext userContextCache = sessionManager.getUserContext();
                    service.update(new UpdateWrapper<DcDrawrecycleInfoEntity>().lambda()
                            .eq(DcDrawrecycleInfoEntity::getId, vo.getId())
                            .set(DcDrawrecycleInfoEntity::getRecycleSts, "Y")
                            .set(DcDrawrecycleInfoEntity::getRecycleCode, billCode.getData())
                            .set(DcDrawrecycleInfoEntity::getRecycleDate, new Date())
                            .set(DcDrawrecycleInfoEntity::getRecycleUserCode, userContextCache.getUserCode())
                            .set(DcDrawrecycleInfoEntity::getRecycleUserName, userContextCache.getUserName()));
                    List<DcDrawrecycleDrwgrpinfoEntity> list = dcDrawrecycleDrwgrpinfoService.list(new QueryWrapper<DcDrawrecycleDrwgrpinfoEntity>().lambda()
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getPid, vo.getId())
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getPaperFlag, "Y")
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getDr, 0)
                            .isNotNull(DcDrawrecycleDrwgrpinfoEntity::getNum));
                    list.stream().collect(Collectors.groupingBy(dcDrawrecycleDrwgrpinfoEntity -> dcDrawrecycleDrwgrpinfoEntity.getDrwgrpCode() + "_" + dcDrawrecycleDrwgrpinfoEntity.getDrwgrpVsn(), Collectors.summarizingInt(DcDrawrecycleDrwgrpinfoEntity::getNum)))
                            .forEach((key, value) -> dcDrwgrpInfoService.update(new UpdateWrapper<DcDrwgrpInfoEntity>().lambda()
                                    .eq(DcDrwgrpInfoEntity::getDrwgrpCode, key.split("_")[0])
                                    .eq(DcDrwgrpInfoEntity::getDrwgrpVsn, key.split("_")[1])
                                    .setSql("surplus_num = surplus_num +" + value.getSum())));
                } else {
                    throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
                }
            }
        }
        return CommonResponse.success("图纸回收成功！");
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DcDrawrecycleInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("drwgrpCode");
        fuzzyFields.add("drwgrpVsn");
        fuzzyFields.add("drwgrpName");
        fuzzyFields.add("issueUserName");
        fuzzyFields.add("recycleCode");
        fuzzyFields.add("recycleUserName");
        fuzzyFields.add("recycleDate");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        Long orgId = InvocationInfoProxy.getOrgId();
        //若当前上下文为项目部，则根据项目部Id来进行查询
        if (OrgVO.ORG_TYPE_DEPARTMENT.equals(Integer.valueOf(InvocationInfoProxy.getOrgType()))) {
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
        } else {
            CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentIdWithoutProjectDept(orgId);
            if (!orgResp.isSuccess()) {
                logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
                return CommonResponse.error("查询失败，获取组织信息失败！");
            }
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));
        pageData.getRecords().forEach(e -> e.setRecycleStsCn(StringUtils.isBlank(e.getRecycleSts()) ? "" : RecycleEnum.getEnumByCode(e.getRecycleSts()).getName()));
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DcDrawrecycleInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DcDrawrecycleInfo-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDcDrawrecycleInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> refDcDrawrecycleInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                               String condition,
                                                                               String searchObject,
                                                                               String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230802.031119-153-sources.jar: com/ejianc/business/dc/controller/DcDrawrecycleInfoController.java <==
package com.ejianc.business.dc.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.basem.service.IAttachmentService;
import com.ejianc.business.dc.bean.DcDrawrecycleDrwgrpinfoEntity;
import com.ejianc.business.dc.bean.DcDrawrecycleInfoEntity;
import com.ejianc.business.dc.bean.DcDrwgrpInfoEntity;
import com.ejianc.business.dc.enumUtils.RecycleEnum;
import com.ejianc.business.dc.enumUtils.YesOrNoEnum;
import com.ejianc.business.dc.service.IDcDrawrecycleDrwgrpinfoService;
import com.ejianc.business.dc.service.IDcDrawrecycleInfoService;
import com.ejianc.business.dc.service.IDcDrwgrpInfoService;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 图纸回收
 *
 * @author generator
 */
@Controller
@RequestMapping("dcDrawrecycleInfo")
public class DcDrawrecycleInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    IAttachmentService iAttachmentService;

    private static final String BILL_CODE = "DC_DRAWRECYCLE_CODE";//此处需要根据实际修改

    @Autowired
    private IDcDrawrecycleInfoService service;

    @Autowired
    private IDcDrawrecycleDrwgrpinfoService dcDrawrecycleDrwgrpinfoService;

    @Autowired
    private IDcDrwgrpInfoService dcDrwgrpInfoService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> saveOrUpdate(@RequestBody DcDrawrecycleInfoVO saveOrUpdateVO) {
        DcDrawrecycleInfoEntity entity = BeanMapper.map(saveOrUpdateVO, DcDrawrecycleInfoEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            entity.setRecycleSts(RecycleEnum.N.getCode());
            entity.setCreateDeptId(sessionManager.getUserContext().getDeptId());
        }
        entity.getDcDrawrecycleDrwgrpinfoList().forEach(dcDrawrecycleDrwgrpinfoEntity -> dcDrawrecycleDrwgrpinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> dcDrawrecycleDrawinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        service.saveOrUpdate(entity, false);
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> iAttachmentService.attachmentFile(
                dcDrawrecycleDrawinfoEntity.getDrawId(),
                "BT230602000000005",
                dcDrawrecycleDrawinfoEntity.getId(),
                "BT230602000000003"));
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> queryDetail(Long id) {
        DcDrawrecycleInfoEntity entity = service.selectById(id);
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        vo.setRecycleStsCn(RecycleEnum.getEnumByCode(vo.getRecycleSts()).getName());
        vo.getDcDrawrecycleDrwgrpinfoList().forEach(v -> v.setPaperFlagCn(YesOrNoEnum.getEnumByCode(v.getPaperFlag()).getName()));
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    @RequestMapping(value = "/recycle", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> recycle(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), vo);
                CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
                if (billCode.isSuccess()) {
                    service.update(new UpdateWrapper<DcDrawrecycleInfoEntity>().lambda()
                            .eq(DcDrawrecycleInfoEntity::getId, vo.getId())
                            .set(DcDrawrecycleInfoEntity::getRecycleSts, RecycleEnum.Y.getCode())
                            .set(DcDrawrecycleInfoEntity::getRecycleCode, billCode.getData())
                            .set(DcDrawrecycleInfoEntity::getRecycleDate, new Date())
                            .set(DcDrawrecycleInfoEntity::getRecycleUserCode, sessionManager.getUserContext().getUserCode())
                            .set(DcDrawrecycleInfoEntity::getRecycleUserName, sessionManager.getUserContext().getUserName()));
                    List<DcDrawrecycleDrwgrpinfoEntity> list = dcDrawrecycleDrwgrpinfoService.list(new QueryWrapper<DcDrawrecycleDrwgrpinfoEntity>().lambda()
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getPid, vo.getId())
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getPaperFlag, YesOrNoEnum.Y.getCode())
                            .eq(DcDrawrecycleDrwgrpinfoEntity::getDr, 0)
                            .isNotNull(DcDrawrecycleDrwgrpinfoEntity::getNum));
                    dcDrwgrpInfoService.update(new UpdateWrapper<DcDrwgrpInfoEntity>().lambda()
                            .eq(vo.getProjectId() != null && vo.getProjectId() != 0, DcDrwgrpInfoEntity::getProjectId, vo.getProjectId())
                            .eq(DcDrwgrpInfoEntity::getDrwgrpCode, vo.getDrwgrpCode())
                            .eq(DcDrwgrpInfoEntity::getDrwgrpVsn, vo.getDrwgrpVsn())
                            .eq(DcDrwgrpInfoEntity::getDr, 0)
                            .setSql("surplus_num = surplus_num +" + list.stream().mapToInt(DcDrawrecycleDrwgrpinfoEntity::getNum).sum()));
                } else {
                    throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
                }
            }
        }
        return CommonResponse.success("图纸回收成功！");
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DcDrawrecycleInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("drwgrpCode");
        fuzzyFields.add("drwgrpVsn");
        fuzzyFields.add("drwgrpName");
        fuzzyFields.add("issueUserName");
        fuzzyFields.add("recycleCode");
        fuzzyFields.add("recycleUserName");
        fuzzyFields.add("recycleDate");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        Long orgId = InvocationInfoProxy.getOrgId();
        //若当前上下文为项目部，则根据项目部Id来进行查询
        if (OrgVO.ORG_TYPE_DEPARTMENT.equals(Integer.valueOf(InvocationInfoProxy.getOrgType()))) {
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
        } else {
            CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentIdWithoutProjectDept(orgId);
            if (!orgResp.isSuccess()) {
                logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
                return CommonResponse.error("查询失败，获取组织信息失败！");
            }
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));
        pageData.getRecords().forEach(e -> e.setRecycleStsCn(StringUtils.isBlank(e.getRecycleSts()) ? "" : RecycleEnum.getEnumByCode(e.getRecycleSts()).getName()));
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DcDrawrecycleInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DcDrawrecycleInfo-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDcDrawrecycleInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> refDcDrawrecycleInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                               String condition,
                                                                               String searchObject,
                                                                               String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}
